/*
    MPC9526 userspace driver
    
    Copyright (c) 2012 Ant Micro <www.antmicro.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301 USA.
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h>
#include "i2c-dev.h"

#define MAX9526_I2C_ADDR	0x21	/* Device address on I2C bus */
#define FD_MAX_LEN		20

void dump(int fd)
{
	int i;
	__s32 reg;

	for (i = 0; i < 16; i++) {
		reg = i2c_smbus_read_byte_data(fd, i);
		if (reg < 0)
			printf("Failed to read 0x%X reg (err: %d)\n", i, reg);
		else
			printf("reg 0x%X: 0x%X\n", i, reg);
	}
}

int main(int argc, char **argv)
{
	int fd; /* file descriptor */
	int adapter_nr = 0;
	char fdname[FD_MAX_LEN];

	if (argc >= 2 && (strcmp(argv[1], "--help") == 0 || strcmp(argv[1], "-h") == 0)) {
		printf("Usage:\n");
		printf("\t%s [i2c-num]\n", argv[0]);
		return 0;
	}

	if (argc >= 2)
		adapter_nr = atoi(argv[1]);

	snprintf(fdname, FD_MAX_LEN - 1, "/dev/i2c-%d", adapter_nr);
	fd = open(fdname, O_RDWR);
	if (fd < 0) {
		printf("Failed to open %s\n", fdname);
		return -1;
	}
	printf("Using %s\n", fdname);

	if (ioctl(fd, I2C_SLAVE, MAX9526_I2C_ADDR) < 0) {
		printf("Failed to set i2c slave address (%d)\n", MAX9526_I2C_ADDR);
		return -2;
	}

	printf("Configuring MAX9526 using I2C...\n");
	if (i2c_smbus_write_byte_data(fd, 0x0d, 0x04) < 0)
		printf("Writing to the register 0xd failed!\n");
	if (i2c_smbus_write_byte_data(fd, 0x09, 0x40))
		printf("Writing to the register 0x9 failed!\n");
	if (i2c_smbus_write_byte_data(fd, 0x0c, 0x03))
		printf("Writing to the register 0xC failed!\n");
	printf("Finished.\n\n");

	printf("Dump:\n");
	dump(fd);

	return 0;
}

